@@ -1,14 +1,11 @@
 # -*- coding: utf-8 -*-
-'''
-Created on Nov 6, 2013
-
-@author: Ricardo Silva
-'''
 from pagseguro.api.base_payment import BasePaymentRequest
 from pagseguro.api.v2 import settings
 from pagseguro.api.v2.schemas import item_schema, client_schema, shipping_schema
 from pagseguro.exceptions import PagSeguroApiException, \
     PagSeguroPaymentException
+from pagseguro.validators import Email
+from voluptuous import Schema, Object, Required, All, Length, Range, Url
 from xml.etree import ElementTree
 import dateutil.parser
 import logging
@@ -20,7 +17,28 @@ logger = logging.getLogger(__name__)
 class Payment(BasePaymentRequest):
     ''' Classe que implementa a requisição à API do PagSeguro versão 2
     
-    TODO: Incluir metadata
+    .. todo:: Adicionar suporte à metadata no checkout 
+
+    Args:
+        email (str): (obrigatório) O email da sua conta no PagSeguro
+        token (str): (obrigatório) O seu token de acesso ao PagSeguro
+        receiver_email (str): (opcional)
+        currency (str): (opcional) A moeda a ser utilizada. Nesta versão apenas o valor BRL é aceito
+            e ele é definido por padrão. Não se preocupe com este parâmetro.
+        reference (str): (opcional) Um identificador para a transação. Você irá utilizar este valor 
+            posteriormente para identificar as transações.
+        extra_amount (float): (opcional) Um valor extra que deve ser adicionado ou subtraído ao valor
+            total do pagamento.
+        redirect_url (str): (opcional)  URL para a qual o comprador será redirecionado após o final
+            do fluxo de pagamento. Tamanho máximo de 255 caracteres.
+        notification_url (str): (opcional)  URL para a qual o PagSeguro enviará os códigos de
+            notificação relacionados ao pagamento. Toda vez que houver uma mudança no status da
+            transação e que demandar sua atenção, uma nova notificação será enviada para este endereço.
+        max_uses (int): Determina o número máximo de vezes que o código de pagamento criado pela chamada
+            à API de Pagamentos poderá ser usado. Este parâmetro pode ser usado como um controle de segurança.        
+        max_age (int): (opcional) Determina o prazo (em segundos) durante o qual o código de pagamento
+            criado pela chamada à API de Pagamentos poderá ser usado. Este parâmetro pode ser usado
+            como um controle de segurança
 
     '''
 
@@ -34,7 +52,7 @@ class Payment(BasePaymentRequest):
                  redirect_url=None,
                  notification_url=None,
                  max_uses=None,
-                 max_age=None):
+                 max_age=None, **kwargs):
 
         self.email = email
         self.token = token
@@ -70,7 +88,10 @@ class Payment(BasePaymentRequest):
         self.items.append(item)
 
     def set_client(self, *args, **kwargs):
-        ''' Inclui dados do comprador
+        ''' Se você possui informações cadastradas sobre o comprador você pode utilizar
+        este método para enviar estas informações para o PagSeguro. É uma boa prática pois
+        evita que seu cliente tenha que preencher estas informações novamente na página
+        do PagSeguro.
 
         Args:
             name (str): (opcional) Nome do cliente
@@ -79,6 +100,12 @@ class Payment(BasePaymentRequest):
             phone_number (str): (opcional) O número de telefone do cliente.
             cpf: (str): (opcional) Número do cpf do comprador
             born_date: (date): Data de nascimento no formato dd/MM/yyyy
+
+        Exemplo:
+            >>> from pagseguro import Payment
+            >>> from pagseguro import local_settings
+            >>> payment = Payment(email=local_settings.PAGSEGURO_ACCOUNT_EMAIL, token=local_settings.PAGSEGURO_TOKEN)
+            >>> payment.set_client(name=u'Adam Yauch', phone_area_code=11)
         '''
         self.client = {}      
         for arg, value in kwargs.iteritems():
@@ -110,9 +137,8 @@ class Payment(BasePaymentRequest):
     def request(self):
         '''
         Faz a requisição de pagamento ao servidor do PagSeguro.
-
-        :returns: str, URL para o cliente continuar o pagamento
         '''
+        payment_v2_schema(self)
         params = self._build_params()
         req = requests.post(
             settings.PAGSEGURO_API_URL,
@@ -158,7 +184,7 @@ class Payment(BasePaymentRequest):
         if self.max_age:
             params['max_age'] = self.max_age
 
-        #TODO: Incluir metadata
+        #TODO: Incluir metadata aqui
 
         # Itens
         for index, item in enumerate(self.items, start=1):
@@ -255,3 +281,25 @@ class Payment(BasePaymentRequest):
             return u'%s?code=%s' % (settings.PAGSEGURO_API_URL, self.response['code'])
         else:
             return None
+
+
+
+#: Schema utilizado para validar os atributos da classe Payment da versão 2 da API
+#: ..todo:: Verificar porque a validação de URLs não está funcionando
+payment_v2_schema = Schema(Object({
+    Required('email'): All(Email(), Length(max=60)),
+    'token': All(str, Length(min=32, max=32)),
+    'receiver_email': All(Email(), Length(max=60)),
+    'currency': 'BRL',
+    'reference': All(str, Length(max=200)),
+    'extra_amount': All(float, Range(min=-9999999.01, max=9999999)),
+    'redirect_url': Url(),
+    'notification_url':Url(),
+    'max_uses': All(int, Range(min=1, max=999)),
+    'max_age': All(int, Range(min=30,max=999999999)),
+    'client': client_schema,
+    'items': [ item_schema, ],
+    'shipping' : shipping_schema,
+    'response': str,
+} ,cls=Payment)
+)
