@@ -1,9 +1,4 @@
 # -*- coding: utf-8 -*-
-'''
-Created on Nov 7, 2013
-
-@author: Ricardo Silva
-'''
 
 PAGSEGURO_API_URL = 'https://ws.pagseguro.uol.com.br/v2/checkout'
 PAGSEGURO_PAYMENT_URL = 'https://pagseguro.uol.com.br/v2/checkout/payment.html'
